export JAVA_HOME="${CONDA_BACKUP_JAVA_HOME}"
unset CONDA_BACKUP_JAVA_HOME
if [ -z ${JAVA_HOME} ]; then
  unset JAVA_HOME
fi

export JAVA_LD_LIBRARY_PATH="${CONDA_BACKUP_JAVA_LD_LIBRARY_PATH}"
unset CONDA_BACKUP_JAVA_LD_LIBRARY_PATH
if [ -z ${JAVA_LD_LIBRARY_PATH} ]; then
  unset JAVA_LD_LIBRARY_PATH
fi
